@@ -44,9 +44,9 @@ GbWidget * gb_gnome_db_list_init ();
 GbWidget *gb_gnome_db_report_init ();
 GbWidget *gb_gnome_db_iconlist_init ();
 GbWidget *gb_gnome_db_designer_init ();
-GbWidget *gb_gnome_db_entry_init ();
+/*GbWidget *gb_gnome_db_entry_init ();*/
 GbWidget *gb_gnome_db_export_init ();
-GbWidget *gb_gnome_db_label_init ();
+/*GbWidget *gb_gnome_db_label_init ();*/
 GbWidget *gb_gnome_db_log_viewer_init ();
 GbWidget *gb_gnome_db_report_init ();
 GbWidget *gb_gnome_db_table_editor_init ();
@@ -65,11 +65,10 @@ static GladeWidgetInitData gnome_db[] = {
         { "GnomeDbError",       gb_gnome_db_error_init },
         { "GnomeDbErrorDlg",    gb_gnome_db_errordlg_init }, 
 	{ "GnomeDbDesigner",	gb_gnome_db_designer_init },
-	{ "GnomeDbEntry",	gb_gnome_db_entry_init },
+	/*{ "GnomeDbEntry",	gb_gnome_db_entry_init },*/
 	{ "GnomeDbExport",	gb_gnome_db_export_init },
-	{ "GnomeDbLabel",	gb_gnome_db_label_init },
+	/*{ "GnomeDbLabel",	gb_gnome_db_label_init },*/
 	{ "GnomeDbLogviewer",	gb_gnome_db_log_viewer_init },
-	{ "GnomeDbReport",	gb_gnome_db_report_init },
 	{ "GnomeDbTableeditor",	gb_gnome_db_table_editor_init },
 	{ NULL, NULL }  
 };
